translate.convert.po2csv

Package translate :: Package convert :: Module po2csv |
[hide private]
[frames] | no frames]

# Module po2csv

source code

convert Gettext PO localization files to Comma-Separated Value (.csv) files

see: http://translate.sourceforge.net/wiki/toolkit/po2csv for examples and usage instructions

Classes | [hide private]
| po2csv

Functions | [hide private]
convertcsv(inputfile, outputfile, templatefile, columnorder=None) reads in inputfile using po, converts using po2csv, writes to outputfile | source code
main(argv=None) | source code

Imports: po, csvl10n